<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        if (!Schema::hasColumn('users', 'last_name') && !Schema::hasColumn('users', 'first_name') && Schema::hasColumn('users', 'name')) {
            Schema::table('users', function (Blueprint $table) {
                $table->renameColumn('name', 'first_name');
                $table->string('last_name', 255)->after('name');
            });
        }

        Schema::table('users', function (Blueprint $table) {
            $table->string('username', 50)->unique()->after('id');
            $table->boolean('active')->default(false);
            $table->string('title', 100)->nullable();
            $table->string('slug', 50)->unique();
            $table->string('display_name', 255)->nullable();
            $table->string('familiar_name', 255)->nullable();
            $table->string('phone_mobile', 24)->nullable();
            $table->string('phone_home', 24)->nullable();
            $table->string('phone_office', 24)->nullable();
            $table->string('photo_url', 255)->nullable();
            $table->boolean('show_online')->default(false);

            $table->softDeletesTz();

            $table->dropUnique('users_email_unique');
            $table->index('email');
            $table->index('active');
            $table->index('show_online');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('users', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['username', 'title', 'slug', 'display_name',
                'familiar_name', 'phone_mobile', 'phone_home',
                'phone_office', 'photo_url', 'show_online', 'active']);

            $table->dropIndex('users_email_index');
            $table->unique('email'); // Default setting for Laravel
            $table->dropSoftDeletesTz();
        });

        if (Schema::hasColumn('users', 'last_name') && Schema::hasColumn('users', 'first_name')) {
            Schema::table('users', function (Blueprint $table) {
                // Revert 'first_name' back to 'name'
                $table->renameColumn('first_name', 'name');
                $table->dropColumn('last_name');
            });
        }
    }
};
