<?php

namespace Neutrino\Ion3Core\Models;

use App\Ion3\Models\Office;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Neutrino\Ion3Core\Database\Factories\BranchFactory;
use Neutrino\Ion3Core\Models\Ion3BranchOfficeSource;

class Ion3Branch extends Model
{
    use HasFactory;

    protected $table = 'branches';
    protected $officeClass = \App\Ion3\Models\Office::class;
    protected $branchMetaClass = \App\Ion3\Models\BranchMeta::class;
    protected $userClass = \App\Models\User::class;
    protected $guarded = ['id', 'deleted_at', 'created_at', 'updated_at'];

    protected static function newFactory()
    {
        return BranchFactory::new();
    }

    public function parent(): BelongsTo
    {
        return $this->belongsTo(self::class, 'parent_id');
    }

    public function child(): HasMany
    {
        return $this->hasMany(self::class, 'parent_id');
    }

    public function offices(): BelongsToMany
    {
        return $this->belongsToMany($this->officeClass, 'offices', 'branch_id');
    }

    public function meta(): HasMany
    {
        return $this->hasMany($this->branchMetaClass, 'branch_id');
    }

    public function users()
    {
        return $this->belongsToMany($this->userClass, 'branch_user', 'branch_id', 'user_id')
            ->withTimestamps();
    }

    public function office_sources(): HasMany
    {
        return $this->hasMany(Ion3BranchOfficeSource::class, 'branch_id');
    }
}
