<?php

namespace Neutrino\Ion3Core\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Neutrino\Ion3Core\Database\Factories\OfficeFactory;

class Ion3Office extends Model
{
    use HasFactory;

    protected $table = 'offices';
    protected $agentClass = \App\Ion3\Models\Agent::class;
    protected $branchClass = \App\Ion3\Models\Branch::class;
    protected $listingClass = \App\Ion3\Models\Listing::class;
    protected $hidden = ['created_at', 'updated_at'];
    protected $guarded = ['id', 'created_at', 'updated_at'];

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
    }

    protected static function newFactory()
    {
        return OfficeFactory::new();
    }

    public function agents(): HasMany
    {
        return $this->hasMany($this->agentClass, 'office_id');
    }

    public function branch(): BelongsTo
    {
        return $this->belongsTo($this->branchClass, 'branch_id');
    }

    public function listings(): BelongsToMany
    {
        return $this->belongsToMany($this->listingClass, 'listing_office', 'office_id', 'listing_id')
            ->withTimestamps()
            ->withPivot('type', 'position', 'active');
    }
}
