<?php

namespace Neutrino\Ion3Core\Traits;

use App\Ion3\Models\Agent;
use App\Ion3\Models\Branch;
use App\Ion3\Models\Listing;
use App\Ion3\Models\UserMeta;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Neutrino\Ion3Core\Models\Ion3UserAgentSource;

trait Ion3UserTrait
{
    public function agents(): HasMany
    {
        return $this->hasMany(Agent::class, 'user_id');
    }

    public function agent_sources(): HasMany
    {
        return $this->hasMany(Ion3UserAgentSource::class, 'user_id');
    }

    public function branches(): BelongsToMany
    {
        return $this->belongsToMany(Branch::class, 'branch_user', 'user_id');
    }

    public function meta(): HasMany
    {
        return $this->hasMany(UserMeta::class, 'user_id');
    }

    public function returnListings($additionalRelations = []) {
        $listings = Listing::whereHas('agents', function ($query) {
            $query->whereIn('agents.id', $this->agents->pluck('id'));
        });

        if (!empty($additionalRelations)) {
            $listings = $listings->with($additionalRelations);
        }

        return $listings;
    }
}
